@@ -40,7 +40,7 @@ insert_spct_hinges <- function(spct, hinges=NULL, byref=FALSE) {
   old.w.length <- spct[["w.length"]]
   hinges <- setdiff(hinges, old.w.length)
   if (length(hinges) > 0) {
-    new.w.length <- unique(sort(c(hinges, old.w.length)))
+#    new.w.length <- unique(sort(c(hinges, old.w.length)))
     name <- substitute(spct)
     names.spct <- names(spct)
     names.data <- names.spct != "w.length"
@@ -58,14 +58,17 @@ insert_spct_hinges <- function(spct, hinges=NULL, byref=FALSE) {
     if (is.reflector_spct(spct) || is.object_spct(spct)) {
       Rfr.type <- getRfrType(spct)
     }
-    new.spct <- dplyr::data_frame(w.length = new.w.length)
+#    new.spct <- dplyr::data_frame(w.length = new.w.length)
     first.iter <- TRUE
     for (data.col in idx.data) {
       temp.data <- spct[[data.col]]
-      if (is.numeric(temp.data)) {
-        new.spct[ , names.spct[data.col] ] <- put_hinges(old.w.length, temp.data, hinges)
+      if (first.iter) {
+        new.spct <- insert_hinges(old.w.length, temp.data, hinges)
+        names(new.spct) <- c("w.length", names.spct[data.col])
+        first.iter <- FALSE
       } else {
-        new.spct[ , names.spct[data.col] ] <- NA
+        new.spct[ , names.spct[data.col] ] <-
+          insert_hinges(old.w.length, temp.data, hinges)[["y"]]
       }
     }
     new.spct <- dplyr::as_data_frame(new.spct)
